Function AddDNS 
{
    [cmdletbinding()]
    Param([string]$dnsServer,[string]$zoneName,[string]$ipAddress,[bool]$createPTR,[string]$vmName,[string]$DNSuserName,[string]$encPassword, [bool]$Is2012orGreater);
    Process{
        #====================== Creates a DNS "A" Record with (optional) PTR ======================

        #Load up the Assembly that holds the decryption method:
        #The path to your DEM must be accurate here. 
        #In the event you have multiple DEMs (Distributed), you can use the commented segment below to work around that.
        <#
        $DEMName = [System.Net.Dns]::GetHostName();
        if ($DEMName.IndexOf("DEM001") -ge 0)
        {
            [reflection.assembly]::LoadFile("[Installation Path for DEM Worker on Server 001]\DynamicOps.Repository.dll");
        }
        else
        {
            [reflection.assembly]::LoadFile("[Installation Path for DEM Worker on Server 002]\DynamicOps.Repository.dll");
        }
        #>
        [reflection.assembly]::LoadFile("E:\Program Files (x86)\VMware\vCAC\Distributed Execution Manager\DEM-WORKER\DynamicOps.Repository.dll");
       
        #Decrypt the password:
        $tmpPwd = [DynamicOps.Repository.ScramblerHelpersClient]::Unscramble($encPassword);
        $pwdDecrypted = $tmpPwd | ConvertTo-SecureString -AsPlainText -Force;
  
        #WinRM Config:
        winrm s winrm/config/client '@{TrustedHosts="' $dnsServer '"}';

        #Create the Credential Object:
        $creds = New-Object -TypeName System.Management.Automation.PSCredential -ArgumentList $DNSuserName, $pwdDecrypted;

        #Is2012orGreater indicates whether the DNS Server is a 2012 Server or Greater. 
        #Only 2012 (or greater) supports the Add-DnsServerResourceRecordA Cmdlet.
        if ($Is2012orGreater -eq $true)
        {
            #Create the remote CimSession (uses RSAT, WinRM)
            $cimSession = New-CimSession -ComputerName $dnsServer -Credential $creds -Authentication Negotiate;
            
            if ($createPTR -eq $true)
            {
                #Add the A Record on the DNS Server, including a Pointer:
                Add-DnsServerResourceRecordA -Name $vmName -ZoneName $zoneName -IPv4Address $ipAddress -CimSession $cimSession -CreatePtr;
            }
            else
            {
                #Add the A Record on the DNS Server, sans Pointer:
                Add-DnsServerResourceRecordA -Name $vmName -ZoneName $zoneName -IPv4Address $ipAddress -CimSession $cimSession;
            }
        }
        else
        {
            #This routine is for Windows 2008 or Windows 2008 R2.
            #These servers support RSAT but not the Add-DnsServerResourceRecordA Cmdlets, so we 
            #have to use DnsCmd.exe, executed remotely.
            $fqdnMachineName = $vmName + "." + $zoneName
            $sesh = New-PSSession -ComputerName $DnsServer -Credential $creds
            Start-Sleep -s 1;
    
            #Add the A Reecord:
            Invoke-Command -Session $sesh -ScriptBlock { 
                    param($server,$zone, $name, $ip)
                    DnsCmd $server /RecordAdd $zone $name A $ip } -ArgumentList ".", $zoneName, $vmName, $IpAddress

            if ($createPTR -eq $true)
            {
                #Create the PTR record - the Reverse Zone MUST EXIST eg "1.168.192.in-addr.arpa"
                $IPAddressArray = $ipAddress.Split(".");
                $IPAddressFormatted = ($IPAddressArray[3]);
                $ReverseZoneName = ($IPAddressArray[2] + "." + $IPAddressArray[1] + "." + $IPAddressArray[0] + ".in-addr.arpa");

                Invoke-Command -Session $sesh -ScriptBlock { 
                    param($server,$zone, $ip, $fqdn)
                    DnsCmd $server /RecordAdd $zone $ip PTR $fqdn } -ArgumentList ".", $ReverseZoneName, $IPAddressFormatted, $fqdnMachineName
            }
            Remove-PSSession $sesh;
        }
    }
}
#clear;
$is2012 = $false;
if ($args[6].toLower() -eq "true"){$is2012 = $true;}
AddDNS -dnsServer $args[0] -zoneName $args[1] -ipAddress $args[2] -createPTR $true -vmName $args[3] -DNSuserName $args[4] -encPassword $args[5] -Is2012orGreater $is2012;