function RemoveDNS
{
 [cmdletbinding()]
    Param([string]$dnsServer,[string]$zoneName,[string]$ipAddress,[bool]$deletePTR,[string]$vmName,[string]$DNSuserName,[string]$encPassword,[bool] $Is2012orGreater);
     Process{

        #====================== Removes a DNS "A" Record with (optional) PTR ======================

        #Load up the Assembly that holds the decryption method:
        #The path to your DEM must be accurate here. 
        #In the event you have multiple DEMs (Distributed), you can use the commented segment below to work around that.
        <#
        $DEMName = [System.Net.Dns]::GetHostName();
        if ($DEMName.IndexOf("DEM001") -ge 0)
        {
            [reflection.assembly]::LoadFile("[Installation Path for DEM Worker on Server 001]\DynamicOps.Repository.dll");
        }
        else
        {
            [reflection.assembly]::LoadFile("[Installation Path for DEM Worker on Server 002]\DynamicOps.Repository.dll");
        }
        #>
        [reflection.assembly]::LoadFile("E:\Program Files (x86)\VMware\vCAC\Distributed Execution Manager\DEM-WORKER\DynamicOps.Repository.dll");
       
        #Decrypt the password:
        $tmpPwd = [DynamicOps.Repository.ScramblerHelpersClient]::Unscramble($encPassword);
        $pwdDecrypted = $tmpPwd | ConvertTo-SecureString -AsPlainText -Force;
  
        #WinRM Config:
        winrm s winrm/config/client '@{TrustedHosts="' $dnsServer '"}';

        #Create the Credential Object:
        $creds = New-Object -TypeName System.Management.Automation.PSCredential -ArgumentList $DNSuserName, $pwdDecrypted;

        #Is2012orGreater indicates whether the DNS Server is a 2012 Server or Greater. 
        #Only 2012 (or greater) supports the Add-DnsServerResourceRecordA Cmdlet.
        if ($Is2012orGreater -eq $true)
        {
            #Create the remote CimSession (uses RSAT)
            $cimSession = New-CimSession -ComputerName $dnsServer -Credential $creds -Authentication Negotiate;
            #Remove the A Record to the DNS Server:
            $NodeDNS = $null;
            $NodePTR = $null;
            $NodeDNS = Get-DnsServerResourceRecord -ZoneName $zoneName -ComputerName $dnsServer -CimSession $cimSession -Node $vmName -RRType A -ErrorAction SilentlyContinue;
            if($NodeDNS -ne $null)
            {
                 Remove-DnsServerResourceRecord -ZoneName $zoneName -ComputerName $dnsServer -CimSession $cimSession -InputObject $NodeDNS -Force;
            } 
            if ($deletePTR -eq $true)
            {   
                #Delete the PTR record
                $IPAddressArray = $ipAddress.Split(".");
                $IPAddressFormatted = ($IPAddressArray[3]+"."+$IPAddressArray[2]);
                $ReverseZoneName = ($IPAddressArray[2] + "." + $IPAddressArray[1] + "." + $IPAddressArray[0] + ".in-addr.arpa");
                $NodePTR = Get-DnsServerResourceRecord -ComputerName $DNSServer -ZoneName $ReverseZoneName -Node $IPAddressFormatted -CimSession $cimSession -RRType Ptr -ErrorAction SilentlyContinue
                if($NodePTR -ne $null)
                {
                    Remove-DnsServerResourceRecord  -ComputerName $dnsServer -ZoneName $ReverseZoneName -CimSession $cimSession -InputObject $NodePTR -Force;
                }
            }
        }
        else
        {
            #This routine is for Windows 2008 or Windows 2008 R2.
            #These servers support RSAT but not the Add-DnsServerResourceRecordA Cmdlets, so we 
            #have to use DnsCmd.exe, executed remotely.

            $sesh = New-PSSession -ComputerName $DnsServer -Credential $creds;

            try
            {
                Start-Sleep -s 1;
    
                #Delete the A Reecord: #dnscmd dnsserver /recorddelete myrootdns.com dnsclient A /f
                Invoke-Command -Session $sesh -ScriptBlock { 
                        param($server,$zone, $name)
                        DnsCmd $server /RecordDelete $zone $name A /f } -ArgumentList ".", $zoneName, $vmName
            
                if ($deletePTR -eq $true)
                {   
                    $IPAddressArray = $ipAddress.Split(".");
                    $IPAddressFormatted = $IPAddressArray[3];
                    $ReverseZoneName = ($IPAddressArray[2] + "." + $IPAddressArray[1] + "." + $IPAddressArray[0] + ".in-addr.arpa");
                    #Delete the PTR Record: dnscmd 10.5.20.5 /RecordDelete 1.1.10.in-addr.arpa. 89 PTR
                    Invoke-Command -Session $sesh -ScriptBlock { 
                            param($server,$zone, $ip)
                            DnsCmd $server /RecordDelete $zone $ip PTR /f} -ArgumentList ".", $ReverseZoneName, $IPAddressFormatted
                }
            }
            catch{}
            finally
            {
             Remove-PSSession $sesh;
            }
           
        }
    }
}
$is2012 = $false;
if ($args[6].toLower() -eq "true"){$is2012 = $true;}
RemoveDNS -dnsServer $args[0] -zoneName $args[1] -ipAddress $args[2] -deletePTR $true -vmName $args[3] -DNSuserName $args[4] -encPassword $args[5] -Is2012orGreater $is2012;






